@@ -16,6 +16,8 @@ class SendTemplateMessage(QueryParams):
     phone = 'phone', 'Contact\'s phone number'
     language = 'language', 'Template message language'
     template_keyword = 'template_keyword', 'Template message keyword'
+    prevent_bot_off = 'prevent_bot_off', 'Prevent turning-off chatbot'
+    agent_id = 'agent_id', 'Assigned agent for the conversation'
 
 
 class SendMessage(QueryParams):
@@ -24,6 +26,8 @@ class SendMessage(QueryParams):
     phone = 'phone', 'Contact\'s phone number'
     text = 'text', 'Message text'
     media_url = 'media_url', 'Media URL for media message'
+    prevent_bot_off = 'prevent_bot_off', 'Prevent turning-off chatbot'
+    agent_id = 'agent_id', 'Assigned agent for the conversation'
 
 
 class ListConversations(QueryParams):
